@@ -1,11 +1,11 @@
-#!/usr/local/bin/python2.5
+#!/usr/local/bin/python2.6
 import sys
 import os
 from svn import client, ra, core
 
 def printer(segment, pool):
   path = segment.path is not None and segment.path or "(null)"
-  print "r%d-r%d: %s" % (segment.range_start, segment.range_end, path)
+  print("r%d-r%d: %s" % (segment.range_start, segment.range_end, path))
 
 
 def parse_args(args):
@@ -42,11 +42,11 @@ def parse_args(args):
   if start_revision >= 0 \
      and end_revision >= 0 \
      and end_revision > start_revision:
-    raise Exception, "End revision must not be younger than start revision"
+    raise Exception("End revision must not be younger than start revision")
   if peg_revision >= 0 \
      and start_revision >= 0 \
      and start_revision > peg_revision:
-    raise Exception, "Start revision must not be younger than peg revision"
+    raise Exception("Start revision must not be younger than peg revision")
 
   return url, peg_revision, start_revision, end_revision
 
